summaryrefslogtreecommitdiff
path: root/fml/lib/FML/PCB.pm
diff options
context:
space:
mode:
authorfukachan <fukachan>2001-01-28 16:43:12 +0000
committerfukachan <fukachan>2001-01-28 16:43:12 +0000
commitc8280b2860fcf7ea6d06ae453fe23a1b601019b0 (patch)
treeedfeaa1de44da46f0e48726b27262ad04107b66b /fml/lib/FML/PCB.pm
parent3d686edce6f92bb67e953c00088716beb5d64f8a (diff)
downloadfml8-c8280b2860fcf7ea6d06ae453fe23a1b601019b0.tar.gz
fml8-c8280b2860fcf7ea6d06ae453fe23a1b601019b0.tar.bz2
fml8-c8280b2860fcf7ea6d06ae453fe23a1b601019b0.zip
s/incoming_mail/incoming_message/
Diffstat (limited to 'fml/lib/FML/PCB.pm')
-rw-r--r--fml/lib/FML/PCB.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/fml/lib/FML/PCB.pm b/fml/lib/FML/PCB.pm
index c98ba603..d4e02389 100644
--- a/fml/lib/FML/PCB.pm
+++ b/fml/lib/FML/PCB.pm
@@ -139,9 +139,9 @@ which are mainly hashes.
# emulator mode though fml mode in fact
emulator => $emulator,
- # struct incoming_mail holds the mail input from STDIN.
- incoming_mail => $r_msg,
- article => $r_msg,
+ # struct incoming_message holds the mail input from STDIN.
+ incoming_message => $r_msg,
+ article => $r_msg,
};
We use r_variable_name syntax where "r_" implies "reference to" here.